pub struct DeviceRevokeParams {
pub endpoint: String,
pub reason: Option<String>,
}Expand description
Params of Request::DeviceRevoke (#85 ask 4).
Fields
endpoint: StringThe eid: principal of the device being revoked — one of THIS person’s own.
Explicit rather than “this node”, because the device you are revoking is usually the one you no longer have: you issue the token from your replacement machine, naming the lost one.
reason: Option<String>Trait Implementations
Sourceimpl Clone for DeviceRevokeParams
impl Clone for DeviceRevokeParams
Sourcefn clone(&self) -> DeviceRevokeParams
fn clone(&self) -> DeviceRevokeParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeviceRevokeParams
impl Debug for DeviceRevokeParams
Sourceimpl<'de> Deserialize<'de> for DeviceRevokeParams
impl<'de> Deserialize<'de> for DeviceRevokeParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DeviceRevokeParams
Sourceimpl PartialEq for DeviceRevokeParams
impl PartialEq for DeviceRevokeParams
Sourceimpl Serialize for DeviceRevokeParams
impl Serialize for DeviceRevokeParams
impl StructuralPartialEq for DeviceRevokeParams